================================================================
 `xotl.tools.decorator.meta`:mod: - Decorator-making facilities
================================================================

.. deprecated:: 3.3.0

   This entire package is deprecated since 3.3.0.  It will be removed in
   3.4.0.

   You can use the excelent package `decorator`__ as a replacement.

__ https://pypi.org/project/decorator/

.. automodule:: xotl.tools.decorator.meta
   :members:
